package Upm4win;
$Upm4win::VERSION = '0.1.3';
# ABSTRACT: User Pass Manager For Windows

=head1 NAME

UserPassManagerForWindows

=head1 VERSION

version 0.1.3

=head2 DESCRIPTION

User Pass Manager For Windows

Commandline Utility

=head2 Usage

See README.md

=cut

1;
